--- transmission-2.84/daemon/daemon.c	2014-07-01 21:10:39.414913066 +0400
+++ transmission-2.84-multiwatch/daemon/daemon.c	2015-02-01 14:36:26.188329665 +0300
@@ -10,6 +10,7 @@
 #include <errno.h>
 #include <stdio.h> /* printf */
 #include <stdlib.h> /* exit, atoi */
+#include <string.h> /* strncpy */
 
 #include <fcntl.h> /* open */
 #include <signal.h>
@@ -61,6 +62,12 @@
 
 #define LOGFILE_MODE_STR "a+"
 
+// one
+typedef struct dtr_watchdir_ptr {
+    dtr_watchdir *watchdir;
+    struct dtr_watchdir_ptr *next;
+} dtr_watchdir_ptr;
+
 static bool paused = false;
 static bool seenHUP = false;
 static const char *logfileName = NULL;
@@ -358,13 +365,15 @@ reportStatus (void)
 }
 
 static void
-periodicUpdate (evutil_socket_t fd UNUSED, short what UNUSED, void *watchdir)
+periodicUpdate (evutil_socket_t fd UNUSED, short what UNUSED, void *watchdir_ptr)
 {
-    dtr_watchdir_update (watchdir);
-
-    pumpLogMessages (logfile);
-
-    reportStatus ();
+    dtr_watchdir_ptr *cur = (dtr_watchdir_ptr *)watchdir_ptr;
+    while(cur) {
+	dtr_watchdir_update (cur->watchdir);
+	cur = cur->next;
+	pumpLogMessages (logfile);
+	reportStatus ();
+    }
 }
 
 static tr_rpc_callback_status
@@ -378,6 +387,8 @@ on_rpc_callback (tr_session            *
     return TR_RPC_OK;
 }
 
+
+
 int
 main (int argc, char ** argv)
 {
@@ -390,7 +401,8 @@ main (int argc, char ** argv)
     bool dumpSettings = false;
     const char * configDir = NULL;
     const char * pid_filename;
-    dtr_watchdir * watchdir = NULL;
+    dtr_watchdir_ptr *watchdir_ptr = NULL;
+    dtr_watchdir_ptr *cur = NULL;
     bool pidfile_created = false;
     tr_session * session = NULL;
     struct event *status_ev;
@@ -592,8 +604,30 @@ main (int argc, char ** argv)
             && dir
             && *dir)
         {
-            tr_logAddInfo ("Watching \"%s\" for new .torrent files", dir);
-            watchdir = dtr_watchdir_new (mySession, dir, onFileAdded);
+		int _i = 1;
+		char *dir_ptr = (char *)dir;
+		char *cfg_part = (char *)dir;
+		watchdir_ptr = malloc(sizeof(dtr_watchdir_ptr));
+		bzero(watchdir_ptr, sizeof(dtr_watchdir_ptr));
+		cur = watchdir_ptr;
+		while(*dir_ptr++) {
+		    if(*dir_ptr == ';') {
+			char *wddir = malloc(_i+1);
+			bzero(wddir, _i+1);
+			strncpy(wddir, cfg_part, _i);
+			cur->watchdir = dtr_watchdir_new (mySession, wddir, onFileAdded);
+			tr_logAddInfo ("[1] Watching \"%s\" for new .torrent files", wddir);
+			cur->next = malloc(sizeof(dtr_watchdir_ptr));
+			bzero(cur->next, sizeof(dtr_watchdir_ptr));
+			cur = cur->next;
+			dir_ptr = cfg_part = dir_ptr+1;
+			_i = 1;
+		    } else {
+			_i++;
+		    }
+		}
+		cur->watchdir = dtr_watchdir_new (mySession, cfg_part, onFileAdded);
+		tr_logAddInfo ("[2] Watching \"%s\" for new .torrent files", cfg_part);
         }
     }
 
@@ -616,7 +650,7 @@ main (int argc, char ** argv)
     /* Create new timer event to report daemon status */
     {
         struct timeval one_sec = { 1, 0 };
-        status_ev = event_new(ev_base, -1, EV_PERSIST, &periodicUpdate, watchdir);
+        status_ev = event_new(ev_base, -1, EV_PERSIST, &periodicUpdate, watchdir_ptr);
         if (status_ev == NULL)
         {
             tr_logAddError("Failed to create status event %s", tr_strerror(errno));
@@ -650,7 +684,14 @@ cleanup:
     event_base_free(ev_base);
 
     tr_sessionSaveSettings (mySession, configDir, &settings);
-    dtr_watchdir_free (watchdir);
+    // multiple
+    cur = watchdir_ptr;
+    while(cur) {
+	dtr_watchdir_ptr *old = cur;
+	dtr_watchdir_free (cur->watchdir);
+	cur = cur->next;
+	free(old);
+    }
     tr_sessionClose (mySession);
     pumpLogMessages (logfile);
     printf (" done.\n");
